#Complete Code

#Create the seed package for PLAase with EC 3.1.1.1
treesapp create \
--fast \
--headless \
-n 4 \
--fastx_input PLAase_seed.fasta \
--seqs2lineage PLAase_lineages.csv \
-m prot \
-c PLAase \
--output PLAase_seed

#Test Purity with TIGERFAM seed
treesapp purity \
  -n 4 \
  -r PLAase_seed/final_outputs/PLAase_build.pkl \
  --extra_info TIGRFAM_info.tsv \
  -i TIGRFAM_seed_named.faa \
  --output PLAase_purity

#For iTOL
treesapp package \
  view tree \
  --refpkg_path PLAase_seed/final_outputs/PLAase_build.pkl > \
  PLAase_seed/PLAase_labelled_tree.txt

# transfer PLAase_seed/PLAase_labelled_tree.txt from server to local directory
scp root@10.32.204.53:/data/capstone_PLA/PLAase_seed/PLAase_labelled_tree.txt .


#assigning MAGs to the seed reference package
treesapp assign \
-n 4 \
--trim_align \
--refpkg_dir PLAase_seed/final_outputs/ \
--fastx_input /mnt/datasets/2021w/saanich/MAGs/Concatenated/All_SI072_Metawrap_MAGs.fa \
--output PLAase_saanich_MAGs_assign/

#update the seed reference package with the MAGs assignment
treesapp update \
  --fast \
  --headless \
  --overwrite \
  --delete \
  --cluster \
  --trim_align \
  -n 4 \
  --output PLAase_MAGs_update/ \
  --skip_assign \
  --seqs2lineage /data/capstone/tutorial/gtdb_MAGS_classifications.tsv \
  --treesapp_output PLAase_saanich_MAGs_assign/ \
  --refpkg_path PLAase_seed/final_outputs/PLAase_build.pkl

#for iTOL
treesapp package \
  view tree \
  --refpkg_path PLAase_MAGs_update/final_outputs/PLAase_build.pkl > \
  PLAase_MAGs_update/PLAase_MAGs_labelled_tree.txt

# transfer PLAase_MAGs_update/PLAase_MAGs_labelled_tree.txt from server to local directory
scp root@10.32.204.53:/data/capstone_PLA/PLAase_MAGs_update/PLAase_MAGs_labelled_tree.txt .

#assigning SAGS to the MAGs updated reference package
treesapp assign \
  -n 4 \
  --trim_align \
  --refpkg_dir PLAase_MAGs_update/final_outputs/ \
  --fastx_input /mnt/datasets/2021w/saanich/SAGs/Concatenated_Med_Plus/Saanich_Med_Plus_SAGs.fasta \
  --output PLAase_saanich_MAGs_update_SAGs_assign/

#update the MAGs-updated reference package with the SAGs assignment
treesapp update \
  --fast \
  --headless \
  --overwrite \
  --delete \
  --cluster \
  --trim_align \
  -n 4 \
  --output PLAase_MAGs_SAGs_update/ \
  --skip_assign \
  --seqs2lineage /data/capstone/tutorial/gtdb_SAGS_classifications.tsv \
  --treesapp_output PLAase_saanich_MAGs_update_SAGs_assign/ \
  --refpkg_path PLAase_MAGs_update/final_outputs/PLAase_build.pkl

# For iTOL
treesapp package \
  view tree \
  --refpkg_path PLAase_MAGs_SAGs_update/final_outputs/PLAase_build.pkl > \
  PLAase_MAGs_SAGs_update/PLAase_MAGs_SAGs_labelled_tree.txt

# transfer PLAase_MAGs_SAGs_update/PLAase_MAGs_SAGs_labelled_tree.txt from server to local directory
scp root@10.32.204.53:/data/capstone_PLA/PLAase_MAGs_SAGs_update/PLAase_MAGs_SAGs_labelled_tree.txt .

#colouring the iTOL tree by phylum
treesapp colour \
-r /root/data/capstone_PLA/PLAase_MAGs_SAGs_update/final_outputs/PLAase_build.pkl \
-o /root/data/capstone_PLA/PLAase_colours/ \
--rank_level phylum

cp -r /root/data/capstone_PLA/PLAase_colours/ /root/data/capstone_PLA/SI072_All_contigs_assign/iTOL_output/

mv /root/data/capstone_PLA/PLAase_colours/ /root/data/capstone_PLA/PLAase_MAGs_SAGs_update_colours

#Makes assignments for all contigs (from every depth)
treesapp assign \
-n 8 \
--trim_align \
--refpkg_dir /root/data/capstone_PLA/PLAase_MAGs_SAGs_update/final_outputs/ \
--fastx_input /mnt/datasets/2021w/saanich/MetaG_Assemblies/SI072_All_contigs.fa \
--output /root/data/capstone_PLA/SI072_All_contigs_assign/

#looping over multiple files in bash
for f in /mnt/datasets/2021w/saanich/MetaG_Assemblies/SI072_*m_contig.fa; do sample=$( basename $f | sed 's/.fa//g'); treesapp assign -i $f \
--refpkg_dir PLAase_MAGs_SAGs_update/final_outputs/ \
--output SI072_MetaG_contigs_PLA_assign/${sample}_assign -n 8; done

#MetaG Abundance Data for Saanich
for depth in 10 100 120 135 150 165 200; do
    treesapp abundance \
        -n 8 \
        --treesapp_output SI072_MetaG_contigs_PLA_assign/SI072_${depth}m_contig_assign \
        --reads /mnt/datasets/2021w/saanich/MetaG_Trim_QC_Reads/SI072_${depth}m_pe.1.fq.gz \
        --reverse /mnt/datasets/2021w/saanich/MetaG_Trim_QC_Reads/SI072_${depth}m_pe.2.fq.gz \
        --report update \
        --metric tpm
done

#save metaG abundances data before running metaT abundance
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_200m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_200m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_165m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_165m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_150m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_150m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_135m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_135m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_120m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_120m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_100m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_100m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_10m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_10m_contig_assign/final_outputs .

#MetaT Abundance Data for Saanich
for depth in 10 100 120 135 150 165 200; do
    treesapp abundance \
    -n 8 \
    --treesapp_output SI072_MetaG_contigs_PLA_assign/SI072_${depth}m_contig_assign \
    --reads /mnt/datasets/2021w/saanich/MetaT_Raw_Reads/SI072_${depth}m_MetaT_QC_Filtered.fastq.gz \
    --pairing pe \
    --metric tpm \
    --report append
done

#save metaT abundance data
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_200m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_200m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_165m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_165m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_150m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_150m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_135m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_135m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_120m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_120m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_100m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_100m_contig_assign/final_outputs .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_10m_contig_assign/iTOL_output .
scp -r root@10.32.204.53:/data/capstone_PLA/SI072_MetaG_contigs_PLA_assign/SI072_10m_contig_assign/final_outputs .






